@@ -9,10 +9,8 @@ import {
   RequestLinksExtractor,
   InvenioRequestEventsApi,
   RequestEventsLinksExtractor,
-} from "./api/api";
-import {
-  Request
-} from './request';
+} from "./api";
+import { Request } from "./request";
 import React, { Component } from "react";
 import PropTypes from "prop-types";
 import { configureStore } from "./store";
@@ -27,7 +25,9 @@ export class InvenioRequestsApp extends Component {
       new RequestLinksExtractor(request)
     );
     const defaultRequestEventsApi = (commentLinks) =>
-      new InvenioRequestEventsApi(new RequestEventsLinksExtractor(commentLinks));
+      new InvenioRequestEventsApi(
+        new RequestEventsLinksExtractor(commentLinks)
+      );
 
     const appConfig = {
       requestsApi: requestsApi || defaultRequestsApi,
