@@ -4,7 +4,7 @@
 // Invenio RDM Records is free software; you can redistribute it and/or modify it
 // under the terms of the MIT License; see LICENSE file for more details.
 
-import { RequestLinkExtractor } from "../../api";
+import { RequestLinksExtractor } from "../../api";
 import React from "react";
 import Overridable from "react-overridable";
 import ReactDOM from "react-dom";
@@ -13,11 +13,11 @@ import { RequestAction } from "./index";
 const element = document.getElementById("request-actions");
 
 export const RequestActions = ({ request }) => {
-  const actions = Object.keys(new RequestLinkExtractor(request).actions);
+  const actions = Object.keys(new RequestLinksExtractor(request).actions);
   return (
     <Overridable id="InvenioRequests.RequestActions.layout" request={request}>
       <>
-        {actions.map((action, url) => (
+        {actions.map((action) => (
           <RequestAction action={action} key={action} />
         ))}
       </>
