@@ -19,7 +19,7 @@ from invenio_records_resources.services.uow import (
     unit_of_work,
 )
 
-from ...customizations.base import RequestActions
+from ...customizations import RequestActions
 from ...errors import CannotExecuteActionError
 from ...proxies import current_events_service, current_registry
 from ...records.api import RequestEventType
@@ -33,7 +33,13 @@ class RequestsService(RecordService):
     @property
     def links_item_tpl(self):
         """Item links template."""
-        return RequestLinksTemplate(self.config.links_item, self.config.action_link)
+        return RequestLinksTemplate(
+            self.config.links_item,
+            self.config.action_link,
+            context={
+                'permission_policy_cls': self.config.permission_policy_cls,
+            }
+        )
 
     @property
     def request_type_registry(self):
@@ -66,10 +72,14 @@ class RequestsService(RecordService):
         )
 
         creator = (
-            ResolverRegistry.reference_entity(creator)
+            ResolverRegistry.reference_entity(creator, raise_=True)
             if creator is not None
             else ResolverRegistry.reference_identity(identity)
         )
+        if topic is not None:
+            topic = ResolverRegistry.reference_entity(topic, raise_=True)
+        if receiver is not None:
+            receiver = ResolverRegistry.reference_entity(receiver, raise_=True)
 
         # Run components
         self.run_components(
@@ -79,11 +89,14 @@ class RequestsService(RecordService):
             record=request,
             errors=errors,
             created_by=creator,
-            topic=ResolverRegistry.reference_entity(topic),
-            receiver=ResolverRegistry.reference_entity(receiver),
+            topic=topic,
+            receiver=receiver,
             uow=uow,
         )
 
+        # Get and run the request type's create action.
+        self._execute(identity, request, request_type.create_action, uow)
+
         # persist record (DB and index)
         uow.register(RecordCommitOp(request, indexer=self.indexer))
 
@@ -100,7 +113,7 @@ class RequestsService(RecordService):
         """Retrieve a request."""
         # resolve and require permission
         request = self.record_cls.get_record(id_)
-        self.require_permission(identity, "read", request=request)
+        self.require_permission(identity, f"read", request=request)
 
         # run components
         for component in self.components:
@@ -122,7 +135,7 @@ class RequestsService(RecordService):
 
         self.check_revision_id(request, revision_id)
 
-        self.require_permission(identity, "update", request=request)
+        self.require_permission(identity, f"update", request=request)
 
         # we're not using "self.schema" b/c the schema may differ per request type!
         schema = self._wrap_schema(request.type.marshmallow_schema())
@@ -156,29 +169,26 @@ class RequestsService(RecordService):
         # self.check_revision_id(request, revision_id)
 
         # check permissions
-        self.require_permission(identity, "delete", request=request)
-
-        # TODO:
-        # prevent deletion if in open state?
+        self.require_permission(identity, f"delete", request=request)
 
         # run components
         self.run_components("delete", identity, record=request, uow=uow)
 
+        # Get and run the request type's create action.
+        self._execute(identity, request, request.type.delete_action, uow)
+
         uow.register(RecordDeleteOp(request, indexer=self.indexer))
+
         return True
 
-    def reindex(self, identity, params=None, es_preference=None, **kwargs):
-        """Reindex records matching the query parameters."""
-        # TODO check later
-        return super().reindex(identity, params=None, es_preference=None, **kwargs)
+    def _execute(self, identity, request, action, uow):
+        """Internal method to execute a given named action."""
+        action_obj = RequestActions.get_action(request, action)
 
-    def rebuild_index(self, identity):
-        """Reindex all records managed by this service."""
-        for req_meta in self.record_cls.model_cls.query.all():
-            request = self._request_from_model(req_meta)
+        if not action_obj.can_execute():
+            raise CannotExecuteActionError(action)
 
-            if not request.is_deleted:
-                self.indexer.index(request)
+        action_obj.execute(identity, uow)
 
     @unit_of_work()
     def execute_action(self, identity, id_, action, data=None, uow=None):
@@ -191,12 +201,13 @@ class RequestsService(RecordService):
         request = self.record_cls.get_record(id_)
         action_obj = RequestActions.get_action(request, action)
 
-        # check permissions
+        # Check permissions - example of permission: can_cancel_submitted
         permission_name = f"action_{action}"
         self.require_permission(identity, permission_name, request=request)
 
-        # Check if the action *can* be executed (i.e. correct status etc.)
-        if not action_obj.can_execute(identity):
+        # Check if the action *can* be executed (i.e. a given state transition
+        # is allowed).
+        if not action_obj.can_execute():
             raise CannotExecuteActionError(action)
 
         # Create action event if defined
