@@ -9,7 +9,7 @@
 
 """Request views module."""
 
-from flask import render_template
+from flask import current_app, render_template
 from flask_login import login_required
 from jinja2 import TemplateNotFound
 
@@ -19,19 +19,24 @@ from invenio_requests.views.decorators import pass_request
 @login_required
 @pass_request
 def requests_detail(request=None, pid_value=None):
-    """Community detail page."""
+    """Requests details page."""
     request_dict = request.to_dict()
     # TODO replace by resolver
     request_dict["topic"] = {}
+    default_query_config = dict(
+        size=current_app.config['REQUESTS_TIMELINE_PAGE_SIZE']
+    )
 
     try:
         return render_template(
             f"invenio_requests/{request_dict['type']}/index.html",
-            request=request_dict,  # TODO: use serializer
+            request=request_dict,  # TODO: use serializer,
+            default_query_config=default_query_config
         )
 
     except TemplateNotFound:
         return render_template(
             "invenio_requests/details/index.html",
-            request=request_dict,  # TODO: use serializer
+            request=request_dict,  # TODO: use serializer,
+            default_query_config=default_query_config
         )
